| sqr.fit | R Documentation |
This function computes spline quantile regression solution with cubic splines and L1-norm roughness penalty (SQR)
from the response vector and the design matrix on a given set of quantile levels.
It uses the FORTRAN code rqfnb.f in the "quantreg" package with the kind permission of Dr. R. Koenker
or the R function rq.fit.sfn() in the same package as a sparse-matrix alternative. Both solve
the SQR problem as a linear program (LP).
sqr.fit(
X,
y,
tau,
tau0 = tau,
spar = 1,
w = rep(1, length(tau0)),
mthreads = TRUE,
ztol = 1e-05,
solver = c("fnb", "sfn"),
all.knots = FALSE
)
X |
design matrix (requirement: |
y |
response vector |
tau |
sequence of quantile levels for evaluation |
tau0 |
sequence of quantile levels for fitting ( |
spar |
smoothing parameter (default = 1) |
w |
weight sequence in penalty (default = |
mthreads |
if |
ztol |
zero-tolerance parameter to determine the model complexity (default = |
solver |
LP solver: |
all.knots |
|
A list with the following elements:
coefficients |
matrix of regression coefficients |
derivatives |
matrix of derivatives of regression coefficients |
crit |
criteria values for spar selection: (AIC,BIC,GIC) |
np |
sequence of complexity measure as the number of effective parameters |
fid |
sequence of fidelity measure as the quasi-likelihood |
info |
convergence status |
nit |
number of iterations |
K |
number of spline basis functions |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.