| sqr.plot | R Documentation |
This function plots one or all regression coefficients from quantile regression (QR) and spline quantile regression (SQR) on a given sequence of quantiles against the quantile level.
sqr.plot(
summary.rq,
summary.sqr = NULL,
summary.sqrb = NULL,
coef.sim = NULL,
type = "l",
lty = c(1, 2),
lwd = c(1.5, 1),
cex = 0.25,
pch = 1,
col = c(2, 1),
idx = NULL,
plot.rq = TRUE,
plot.rq.line = FALSE,
plot.zero = FALSE,
plot.ls = TRUE,
plot.ci = TRUE,
var.names = NULL,
Ylim = NULL,
xlim = NULL,
set.par = TRUE,
mfrow = NULL,
lab = c(10, 7, 7),
mar = c(2, 3, 2, 1) + 0.1,
las = 1
)
summary.rq |
output of |
summary.sqr |
output of |
summary.sqrb |
output of |
coef.sim |
output |
type |
as |
lty |
line types for the primary and secondary SQR (default = |
lwd |
line widths for the primary and secondary SQR (default = |
cex |
as |
pch |
as |
col |
line colors for the primary and secondary SQR (default = |
idx |
index of individual coefficient to be plotted (default = |
plot.rq |
|
plot.rq.line |
|
plot.zero |
|
plot.ls |
|
plot.ci |
|
var.names |
user-supplied names of regression coefficients (including the intercept) |
Ylim |
user-supplied matrix of |
xlim |
user-supplied |
set.par |
|
mfrow |
parameter for resetting |
lab |
parameter for resetting |
mar |
parameter for resetting |
las |
parameter for resetting |
Ylim (invisible)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.