sqr_deriv.plot: Plot of Derivative of Spline Quantile Regression Coefficients

View source: R/qfa5.0.R

sqr_deriv.plotR Documentation

Plot of Derivative of Spline Quantile Regression Coefficients

Description

This function plots the derivative of one or all coefficients from spline quantile regression (SQR) together with the corresponding first difference from quantile regression (QR) on a given sequence of quantiles against the quantile level.

Usage

sqr_deriv.plot(
  fit,
  fit.sqr,
  fit.sqrb = NULL,
  deriv.sim = NULL,
  type = "l",
  typeb = "s",
  var.names = NULL,
  lty = c(1, 2),
  lwd = c(1.5, 1),
  cex = 0.25,
  pch = 1,
  col = c(2, 1),
  idx = NULL,
  Ylim = NULL,
  xlim = NULL,
  plot.zero = TRUE,
  plot.ci = TRUE,
  set.par = TRUE,
  mfrow = NULL,
  lab = c(10, 7, 7),
  mar = c(2, 3, 2, 1) + 0.1,
  las = 1
)

Arguments

fit

output of quantreg::rq() for the QR fit

fit.sqr

output of sqr() for the primary SQR fit

fit.sqrb

output of sqr() for the secondary SQR fit (default = NULL)

deriv.sim

output derivatives of boot.sqr() for the primary SQR (default = NULL)

type

as type parameter in plot() for the primary SQR (default = "l")

typeb

as type parameter in plot() for the secondary SQR (default = "s")

var.names

user-supplied names of regression coefficients (including the intercept)

lty

line types for the primary and secondary SQR (default = c(1,2))

lwd

line widths for the primary and secondary SQR (default = c(1.5,1))

cex

as cex parameter in plot()

pch

as pch parameter in plot() for QR(default = 1)

col

line colors for the primary and secondary SQR (default = c(2,1))

idx

index of individual coefficient to be plotted (default = NULL)

Ylim

user-supplied matrix of ylim for each coefficient (default = NULL)

xlim

user-supplied xlim (default = NULL)

plot.zero

TRUE or FALSE (default): if TRUE, add zero line

plot.ci

TRUE (default) or FALSE: if TRUE, add 90-percent bootstrap CI for the primary SQR when deriv.sim is supplied

set.par

TRUE (default) or FALSE if TRUE, reset par()

mfrow

parameter for resetting par() (default = NULL)

lab

parameter for resetting par() (default = c(10,7,7))

mar

parameter for resetting par() (default = c(2,3,2,1)+0.1)

las

parameter for resetting par() (default = 1)

Value

Ylim (invisible)


qfa documentation built on March 30, 2026, 5:07 p.m.

Related to sqr_deriv.plot in qfa...