| sqdft | R Documentation |
This function computes spline quantile discrete Fourier transform (SQDFT) for univariate or multivariate time series through trigonometric spline quantile regression.
sqdft(
y,
tau,
tau0 = tau,
spar = NULL,
w = rep(1, length(tau0)),
criterion = c("AIC", "BIC", "GIC"),
method = c("sqr", "sqr1", "sqr3"),
ztol = NULL,
solver = NULL,
interval = NULL,
all.knots = FALSE,
control = list(),
n.cores = 1,
cl = NULL
)
y |
vector or matrix of time series (if matrix, |
tau |
sequence of quantile levels for evaluation |
tau0 |
sequence of quantile levels for fitting ( |
spar |
smoothing parameter, selected automatically by |
w |
weight sequence in penalty (default = |
criterion |
criterion for smoothing parameter selection: |
method |
|
ztol |
zero-tolerance parameter to determine the model complexity
(default = |
solver |
|
interval |
interval for |
all.knots |
|
control |
list of control parameters for QP solvers |
n.cores |
number of cores for parallel computing (default = 1) |
cl |
pre-existing cluster for repeated parallel computing (default = |
A list with the following elements:
coefficients |
matrix of regression coefficients |
qdft |
matrix or array of the spline quantile discrete Fourier transform of |
crit |
criteria for smoothing parameter selection: (AIC,BIC,GIC) |
nit |
maximum number of iterations |
spar |
optimal value of smoothing parameter |
y <- stats::arima.sim(list(order=c(1,0,0), ar=0.5), n=64)
tau <- seq(0.1,0.9,0.05)
y.sqdft <- sqdft(y,tau,spar=0.2,method="sqr1")$qdft
plot(y.sqdft[,2])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.