This function computes spline quantile regression solution with cubic splines and L1-norm roughness penalty (SQR)
from the response vector and the design matrix on a given set of quantile levels.
It uses the FORTRAN code rqfnb.f in the "quantreg" package with the kind permission of Dr. R. Koenker
or the R function rq.fit.sfn() in the same package as a sparse-matrix alternative. Both solve
the SQR problem as a linear program (LP).
sqr.fit(
X,
y,
tau,
tau0 = tau,
spar = 1,
w = rep(1, length(tau0)),
mthreads = TRUE,
ztol = 1e-05,
solver = c("fnb", "sfn"),
all.knots = FALSE
)A list with the following elements:
matrix of regression coefficients
matrix of derivatives of regression coefficients
criteria values for spar selection: (AIC,BIC,GIC)
sequence of complexity measure as the number of effective parameters
sequence of fidelity measure as the quasi-likelihood
convergence status
number of iterations
number of spline basis functions
design matrix (requirement: nrow(X) = length(y))
response vector
sequence of quantile levels for evaluation
sequence of quantile levels for fitting (min(tau0) <= tau <= max(tau0);
default = tau)
smoothing parameter (default = 1)
weight sequence in penalty (default = rep(1,length(tau0)))
if FALSE, set RhpcBLASctl::blas_set_num_threads(1) (default = TRUE)
zero-tolerance parameter to determine the model complexity (default = 1e-05)
LP solver: 'fnb' (defaut) or 'sfn'
TRUE or FALSE (default), same as in smooth.spline()