Learn R Programming

qfa (version 5.0)

sqr.plot: Plot of Spline Quantile Regression Coefficients

Description

This function plots one or all regression coefficients from quantile regression (QR) and spline quantile regression (SQR) on a given sequence of quantiles against the quantile level.

Usage

sqr.plot(
  summary.rq,
  summary.sqr = NULL,
  summary.sqrb = NULL,
  coef.sim = NULL,
  type = "l",
  lty = c(1, 2),
  lwd = c(1.5, 1),
  cex = 0.25,
  pch = 1,
  col = c(2, 1),
  idx = NULL,
  plot.rq = TRUE,
  plot.rq.line = FALSE,
  plot.zero = FALSE,
  plot.ls = TRUE,
  plot.ci = TRUE,
  var.names = NULL,
  Ylim = NULL,
  xlim = NULL,
  set.par = TRUE,
  mfrow = NULL,
  lab = c(10, 7, 7),
  mar = c(2, 3, 2, 1) + 0.1,
  las = 1
)

Value

Ylim (invisible)

Arguments

summary.rq

output of summary() for the QR fit from quantreg::rq()

summary.sqr

output of summary() for the primary SQR fit from sqr() (defalty = NULL)

summary.sqrb

output of summary() for the secondary SQR fit from sqr() (default = NULL)

coef.sim

output coefficients of boot.sqr() for the primary SQR (default = NULL)

type

as type parameter in plot() for plotting SQR (default = "l")

lty

line types for the primary and secondary SQR (default = c(1,2))

lwd

line widths for the primary and secondary SQR (default = c(1.5,1))

cex

as cex parameter in plot()

pch

as pch parameter in plot() for the QR (default = 1)

col

line colors for the primary and secondary SQR (default = c(2,1))

idx

index of individual coefficient to be plotted (default = NULL)

plot.rq

TRUE (default) or FALSE: if TRUE, plot QR as points

plot.rq.line

TRUE or FALSE (default): if TRUE, add line plot of QR

plot.zero

TRUE or FALSE (default): if TRUE, add zero line

plot.ls

TRUE (default) or FALSE: if TRUE, add least-square estimate with 90-percent CI

plot.ci

TRUE (default) or FALSE: if TRUE, add 90-percent bootstrap CI for the primary SQR when coef.sim is supplied or approximate CI when coef.sim = NULL

var.names

user-supplied names of regression coefficients (including the intercept)

Ylim

user-supplied matrix of ylim for each coefficient (default = NULL)

xlim

user-supplied xlim (default = NULL)

set.par

TRUE (default) or FALSE if TRUE, reset par()

mfrow

parameter for resetting par() (default = NULL)

lab

parameter for resetting par() (default = c(10,7,7))

mar

parameter for resetting par() (default = c(2,3,2,1)+0.1)

las

parameter for resetting par() (default = 1)