This function computes spline quantile regression with linear splines and total-variation roughness penalty
(SQR1 or linear SQR) from the response vector and the design matrix on a given set of quantile levels.
It uses the FORTRAN code rqfnb.f in the "quantreg" package with the kind permission of Dr. R. Koenker
or the R function rq.fit.sfn() in the same package as a sparse-matrix alternative. Both solve the SQR1 problem as a linear program (LP).
sqr1.fit(
X,
y,
tau,
tau0 = tau,
spar = 1,
w = rep(1, length(tau0) - 1),
mthreads = FALSE,
ztol = 1e-05,
solver = c("fnb", "sfn"),
npar = c(1, 2),
all.knots = FALSE
)A list with the following elements:
matrix of regression coefficients
matrix of derivatives of regression coefficients
sequence critera for smoothing parameter select: (AIC,BIC,GIC)
sequence of complexity measure as the number of effective parameters
sequence of fidelity measure as the quasi-likelihood
number of iterations
convergence status
number of spline basis functions
design matrix (nrow(X) = length(y))
response vector
sequence of quantile levels for evaluation
sequence of quantile levels for fitting (min(tau0) <= tau <= max(tau0);
default = tau)
smoothing parameter (default = 1)
weight sequence in penalty (default = rep(1,length(tau0)-1))
if FALSE (default), set RhpcBLASctl::blas_set_num_threads(1)
zero-tolerance parameter to determine the model complexity (default = 1e-05)
LP solver: 'fnb' (defaut) or 'sfn'
experimental parameter (default = 1)
TRUE or FALSE (default), same as in stats::smooth.spline()