| sqr3.fit | R Documentation |
This function computes spline quantile regression with cubic splines and L2-norm roughness penalty
(SQR3 or cubic SQR) from the response vector and the design matrix on a given set of quantile levels.
It uses solve_osqp() in the "osqp" package or solve_piqp() in the "piqp" package.
Both are general-purpose quadratic program (QP) solvers in the sparse-matrix form.
sqr3.fit(
X,
y,
tau,
tau0 = tau,
spar = 1,
w = rep(1, length(tau0)),
mthreads = FALSE,
ztol = 1e-04,
type = c("dual", "primal"),
solver = c("piqp", "osqp"),
npar = c(1, 2),
all.knots = FALSE,
control = list()
)
X |
design matrix (requirement: |
y |
response vector |
tau |
sequence of quantile levels for evaluation |
tau0 |
sequence of quantile levels for fitting ( |
spar |
smoothing parameter (default = 1) |
w |
weight sequence in penalty (default = |
mthreads |
if |
ztol |
zero-tolerance parameter to determine the model complexity (default = |
type |
type of QP formulation: |
solver |
QP solver: |
npar |
experimental parameter (default = 1) |
all.knots |
|
control |
list of control parameters for the QP solver (default = |
A list with the following elements:
coefficients |
matrix of regression coefficients |
derivatives |
matrix of derivatives of regression coefficients |
crit |
sequence critera for smoothing parameter select: (AIC,BIC,GIC) |
np |
sequence of complexity measure as the number of effective parameters |
fid |
sequence of fidelity measure as the quasi-likelihood |
info |
convergence status |
nit |
number of iterations |
K |
number of spline basis functions |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.