| sqr_deriv.plot | R Documentation |
This function plots the derivative of one or all coefficients from spline quantile regression (SQR) together with the corresponding first difference from quantile regression (QR) on a given sequence of quantiles against the quantile level.
sqr_deriv.plot(
fit,
fit.sqr,
fit.sqrb = NULL,
deriv.sim = NULL,
type = "l",
typeb = "s",
var.names = NULL,
lty = c(1, 2),
lwd = c(1.5, 1),
cex = 0.25,
pch = 1,
col = c(2, 1),
idx = NULL,
Ylim = NULL,
xlim = NULL,
plot.zero = TRUE,
plot.ci = TRUE,
set.par = TRUE,
mfrow = NULL,
lab = c(10, 7, 7),
mar = c(2, 3, 2, 1) + 0.1,
las = 1
)
fit |
output of |
fit.sqr |
output of |
fit.sqrb |
output of |
deriv.sim |
output |
type |
as |
typeb |
as |
var.names |
user-supplied names of regression coefficients (including the intercept) |
lty |
line types for the primary and secondary SQR (default = |
lwd |
line widths for the primary and secondary SQR (default = |
cex |
as |
pch |
as |
col |
line colors for the primary and secondary SQR (default = |
idx |
index of individual coefficient to be plotted (default = |
Ylim |
user-supplied matrix of |
xlim |
user-supplied |
plot.zero |
|
plot.ci |
|
set.par |
|
mfrow |
parameter for resetting |
lab |
parameter for resetting |
mar |
parameter for resetting |
las |
parameter for resetting |
Ylim (invisible)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.