This function plots the derivative of one or all coefficients from spline quantile regression (SQR) together with the corresponding first difference from quantile regression (QR) on a given sequence of quantiles against the quantile level.
sqr_deriv.plot(
fit,
fit.sqr,
fit.sqrb = NULL,
deriv.sim = NULL,
type = "l",
typeb = "s",
var.names = NULL,
lty = c(1, 2),
lwd = c(1.5, 1),
cex = 0.25,
pch = 1,
col = c(2, 1),
idx = NULL,
Ylim = NULL,
xlim = NULL,
plot.zero = TRUE,
plot.ci = TRUE,
set.par = TRUE,
mfrow = NULL,
lab = c(10, 7, 7),
mar = c(2, 3, 2, 1) + 0.1,
las = 1
)Ylim (invisible)
output of quantreg::rq() for the QR fit
output of sqr() for the primary SQR fit
output of sqr() for the secondary SQR fit (default = NULL)
output derivatives of boot.sqr() for the primary SQR (default = NULL)
as type parameter in plot() for the primary SQR (default = "l")
as type parameter in plot() for the secondary SQR (default = "s")
user-supplied names of regression coefficients (including the intercept)
line types for the primary and secondary SQR (default = c(1,2))
line widths for the primary and secondary SQR (default = c(1.5,1))
as cex parameter in plot()
as pch parameter in plot() for QR(default = 1)
line colors for the primary and secondary SQR (default = c(2,1))
index of individual coefficient to be plotted (default = NULL)
user-supplied matrix of ylim for each coefficient (default = NULL)
user-supplied xlim (default = NULL)
TRUE or FALSE (default): if TRUE, add zero line
TRUE (default) or FALSE: if TRUE, add 90-percent bootstrap CI for the primary SQR
when deriv.sim is supplied
TRUE (default) or FALSE if TRUE, reset par()
parameter for resetting par() (default = NULL)
parameter for resetting par() (default = c(10,7,7))
parameter for resetting par() (default = c(2,3,2,1)+0.1)
parameter for resetting par() (default = 1)